@@ -1,13 +1,21 @@
 from collections import defaultdict
 from typing import Any, Dict, List, NamedTuple, Optional, Tuple, Union
 
+from bridger.serializers import percent_decorator
+
 
 class BaseField(NamedTuple):
     key: str
     label: str
 
+    decorators: List = None
+
     def to_dict(self):
-        return {"key": self.key, "label": self.label, "type": self.type}
+        base = {"key": self.key, "label": self.label, "type": self.type}
+        if self.decorators:
+            base["decorators"] = self.decorators
+
+        return base
 
 
 class PKField(BaseField):
@@ -26,16 +34,29 @@ class FloatField(NamedTuple):
     key: str
     label: str
     precision: int = 2
+    percent: bool = False
+    decorators: List = None
     type = "number"
 
     def to_dict(self):
-        return {
+        base = {
             "key": self.key,
             "label": self.label,
             "type": self.type,
             "precision": self.precision,
         }
 
+        if self.percent:
+            base["type"] = "percent"
+
+            if not self.decorators:
+                base["decorators"] = [percent_decorator]
+
+        if self.decorators:
+            base["decorators"] = self.decorators
+
+        return base
+
 
 class IntegerField(FloatField):
     type = "number"
